build initramfs: speedup
Get series with b4
b4 am [email protected]Versions newest first
- v1 Latest8 patches 4 repliesIn review
Patches in v1 No applies recorded yet
| # | Subject and files | Size | Replies | Applied |
|---|---|---|---|---|
| 1/8 | inst_simple, inst_dir: make fast case fasterdracut-functions | +5 | 0 replies | |
| 2/8 | filter_kernel_modules is a specialized filter_kernel_modules_by_pathdracut-functions | +3 | 0 replies | |
| 3/8 | install_kmod_with_fw: make fast case fasterdracut-functions | +3 | 0 replies | |
| 4/8 | instmods: get filenames from stdin if no args; use itdracut-functions modules.d/ modules.d/ +2 more | +83 | 0 replies | |
| 5/8 | instmods: sanity for _mpargsdracut-functions | +7 | 0 replies | |
| 6/8 | instmods: factor out egrep of "FATAL: Module .* not found"dracut-functions | +19 | 0 replies | |
| 7/8 | build initramfs: cpio avoids per-file /bin/cpdracut dracut-functions | +21 | 0 replies | |
| 8/8 | Close original fd after bash-generated high redirection.dracut dracut-functions | +3 | 0 replies |
Reviews trailers per patch
No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.
Cover letter [PATCH 0/8] build initramfs: speedup
This patch series saves 50% (a factor of 2) in real time before final gzip when building initramfs for Fedora 16.
Probably you should apply only the first six patches (1,2,3,4,5,6) because directory symlinks and permissions aren't right after patch 7. [I don't care about directory symlinks now; permissions are 775 instead of 755.] I'm working on a different approach for those; it's not ready. However, the first six patches save 25% (a factor of 4/3),
and patch 7 saves another 25% by replacing most /bin/cp with cpio.